@@ -18,7 +18,7 @@ Usage::
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Generator, TYPE_CHECKING
+from typing import Iterator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_codebuild.type_defs import (
     ListBuildsForProjectOutputTypeDef,
@@ -38,22 +38,22 @@ __all__ = ("ListBuildsPaginator", "ListBuildsForProjectPaginator", "ListProjects
 
 class ListBuildsPaginator(Boto3Paginator):
     """
-    [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
+    [Paginator.ListBuilds documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds)
     """
 
     def paginate(
         self,
         sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListBuildsOutputTypeDef, None, None]:
+    ) -> Iterator[ListBuildsOutputTypeDef]:
         """
-        [ListBuilds.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
+        [ListBuilds.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codebuild.html#CodeBuild.Paginator.ListBuilds.paginate)
         """
 
 
 class ListBuildsForProjectPaginator(Boto3Paginator):
     """
-    [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
+    [Paginator.ListBuildsForProject documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject)
     """
 
     def paginate(
@@ -61,15 +61,15 @@ class ListBuildsForProjectPaginator(Boto3Paginator):
         projectName: str,
         sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListBuildsForProjectOutputTypeDef, None, None]:
+    ) -> Iterator[ListBuildsForProjectOutputTypeDef]:
         """
-        [ListBuildsForProject.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
+        [ListBuildsForProject.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codebuild.html#CodeBuild.Paginator.ListBuildsForProject.paginate)
         """
 
 
 class ListProjectsPaginator(Boto3Paginator):
     """
-    [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
+    [Paginator.ListProjects documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects)
     """
 
     def paginate(
@@ -77,7 +77,7 @@ class ListProjectsPaginator(Boto3Paginator):
         sortBy: Literal["NAME", "CREATED_TIME", "LAST_MODIFIED_TIME"] = None,
         sortOrder: Literal["ASCENDING", "DESCENDING"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
-    ) -> Generator[ListProjectsOutputTypeDef, None, None]:
+    ) -> Iterator[ListProjectsOutputTypeDef]:
         """
-        [ListProjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.13/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
+        [ListProjects.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/codebuild.html#CodeBuild.Paginator.ListProjects.paginate)
         """
